pub enum PublicKey {
EcdsaP256(VerifyingKey),
}Variants
EcdsaP256(VerifyingKey)
Implementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn signature_algorithm(&self) -> SignatureAlgorithm
pub fn signature_algorithm(&self) -> SignatureAlgorithm
The signature algorithm used by this key
Sourcepub fn verify(
&self,
msg: &[u8],
signature: &Signature,
) -> Result<(), SignatureError>
pub fn verify( &self, msg: &[u8], signature: &Signature, ) -> Result<(), SignatureError>
Verify that a given message and signature were signed by the private key associated with this public key
Sourcepub fn fingerprint(&self) -> KeyID
pub fn fingerprint(&self) -> KeyID
Compute the digest of this key